| Title: | Addins Made of Joao Melo |
|---|---|
| Description: | Provide addins for 'RStudio'. It currently contains 3 addins. The first to add a shortcut for the double pipe. The second is to add a shortcut for the same operator. And the third to simplify the creation of vectors from texts pasted from the computer transfer area. |
| Authors: | Joao Melo [aut, cre] |
| Maintainer: | Joao Melo <[email protected]> |
| License: | CC0 |
| Version: | 0.1.0 |
| Built: | 2026-05-13 06:22:53 UTC |
| Source: | https://github.com/cran/addinsJoaoMelo |
Simplify mode of create vector in RStudio
bare_combine()bare_combine()
## Not run: bare_combine()## Not run: bare_combine()
Add %<>% pipe in line of code in RStudio
insert_compound_assignment_pipe()insert_compound_assignment_pipe()
## Not run: insert_compound_assignment_pipe()## Not run: insert_compound_assignment_pipe()
Add = operator in line of code in RStudio
insert_equal()insert_equal()
## Not run: insert_equal()## Not run: insert_equal()